Crate protobuf_macros

Crate protobuf_macros 

Macros

proto_proc
proto! enables the use of Rust struct initialization syntax to create protobuf messages. The macro does its best to try and detect the initialization of submessages, but it is only able to do so while the submessage is being defined as part of the original struct literal. Introducing an expression using () or {} as the value of a field will require another call to this macro in order to return a submessage literal.